@@ -8,9 +8,9 @@ ct2df <- function(ct, tt){
       if (missing(ct)) ct <- tt
     }
   
-  if (is.null(attr(ct, "n", exact = TRUE))) return(as.data.frame(ct))
+  if (is.null(attr(ct, "n", exact = TRUE))) return(as.data.frame(ct, warn = FALSE))
   n <- nrow(ct)
-  df <- as.data.frame(ct)[rep(seq_len(n), attr(ct, "n")), , drop = FALSE]
+  df <- as.data.frame(ct, warn = FALSE)[rep(seq_len(n), attr(ct, "n")), , drop = FALSE]
   rownames(df) <- unlist(attr(ct, "cases"), use.names = FALSE, recursive = FALSE)
   attributes(df) <- attributes(df)[c("names", "row.names", "class")]
   df
